data <- read.table("babies.dat",skip=2,header=T)
attach(data)

summary(z0 <- glm(Weight~1))
print(sigma0 <- sum(residuals(z0)^2)/24)
12*log(sigma0)+2
summary(z1 <- glm(Weight~Age))
print(sigma1 <- sum(residuals(z1)^2)/24)
sqrt(sigma1)
12*log(sigma1)+3
24*log(sigma0/sigma1)
summary(z2 <- glm(Weight~Age+Sex))
print(sigma2 <- sum(residuals(z2)^2)/24)
12*log(sigma2)+4
summary(z3 <- glm(Weight~Age*Sex))
print(sigma3 <- sum(residuals(z3)^2)/24)
12*log(sigma3)+5

slope1 <- coef(z1)[2]
se1 <- coef(summary(z1))[2,2]
points1 <- seq(slope1-3*se1,slope1+3*se1,by=1)
lr1 <- rep(0,length(points1))
for(i in 1:length(points1)){
      lr1[i] <- deviance(glm(Weight~1,offset=Age*points1[i]))}
lr1 <- (lr1/deviance(z1))^(-12)

slope2 <- coef(z2)[2]
se2 <- coef(summary(z2))[2,2]
points2 <- seq(slope2-3*se2,slope2+3*se2,by=1)
lr2 <- rep(0,length(points2))
for(i in 1:length(points2)){
      lr2[i] <- deviance(glm(Weight~Sex,offset=Age*points2[i]))}
lr2 <- (lr2/deviance(z2))^(-12)

slope3 <- coef(z2)[3]
se3 <- coef(summary(z2))[3,2]
points3 <- seq(slope3-3*se3,slope3+3*se3,by=4)
lr3 <- rep(0,length(points3))
for(i in 1:length(points3)){
      lr3[i] <- deviance(glm(Weight~Age,offset=(Sex=="Male")*points3[i]))}
lr3 <- (lr3/deviance(z2))^(-12)

if(interactive()){
postscript("babies.eps",height=6,width=6)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(Age,Weight,pch=20,xlab="Age (weeks)",ylab="Weight (g)")
abline(z1)
abline(a=coef(z1)[1]+sqrt(sigma1),b=coef(z1)[2],lty=2)
abline(a=coef(z1)[1]-sqrt(sigma1),b=coef(z1)[2],lty=2)
abline(a=coef(z1)[1]+2*sqrt(sigma1),b=coef(z1)[2],lty=3)
abline(a=coef(z1)[1]-2*sqrt(sigma1),b=coef(z1)[2],lty=3)
legend(35,3500,legend=c("Regression line","1 standard deviation",
	"2 standard deviations"),lty=1:3,bty="n")
dev.off()
postscript("babies2.eps",height=6,width=6)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(Age[1:12],Weight[1:12],pch=20,xlab="Age (weeks)",ylab="Weight (g)")
points(Age[13:24],Weight[13:24])
abline(coef(z2)[1],coef(z2)[2])
abline(coef(z2)[1]+coef(z2)[3],coef(z2)[2],lty=2)
legend(35,3400,legend=c("Female","Male"),lty=1:2,pch=c(1,20),bty="n")
dev.off()
postscript("babieslike1.eps",height=6,width=6)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(points1,exp(-(points1-slope1)^2/(2*se1^2)),type="l",
	xlab=expression(beta[1]),ylab=expression(R(beta[1])),lty=2)
lines(points1,lr1)
legend(50,1,legend=c("Profile likelihood","Standard error",
	"  approximation"),lty=c(1,2,0),bty="n")
dev.off()
postscript("babieslike2.eps",height=6)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(points2,exp(-(points2-slope2)^2/(2*se2^2)),type="l",
	xlab=expression(beta[1]),ylab=expression(R(beta[1])),lty=2)
lines(points2,lr2)
legend(75,0.15,legend=c("Profile likelihood","Standard error",
	"  approximation"),lty=c(1,2,0),bty="n")
plot(points3,exp(-(points3-slope3)^2/(2*se3^2)),type="l",
	xlab=expression(beta[2]),ylab=expression(R(beta[2])),lty=2)
lines(points3,lr3)
dev.off()
}
